@@ -25,7 +25,7 @@ from django.conf import settings
 from django.contrib import auth
 from django.contrib.auth import decorators as auth_dec
 from django.contrib.staticfiles.templatetags.staticfiles import static
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 # django.contrib.formtools migration to django 1.8
 # https://docs.djangoproject.com/en/1.8/ref/contrib/formtools/
 try:
@@ -212,7 +212,7 @@ def clear_forms_data(func):
         LOG.debug('Clearing forms data for application {0}.'.format(fqn))
         services.get_apps_data(request)[app_id] = {}
         LOG.debug('Clearing any leftover wizard step data.')
-        for key in request.session.keys():
+        for key in list(request.session.keys()):
             # TODO(tsufiev): unhardcode the prefix for wizard step data
             if key.startswith('wizard_wizard'):
                 request.session.pop(key)
@@ -407,7 +407,7 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
             messages.success(self.request, message)
 
             if do_redirect:
-                return http.HttpResponseRedirect(env_url)
+                return http.HttpResponseRedirect(six.text_type(env_url))
             else:
                 srv_id = getattr(srv, '?')['id']
                 return self.create_hacked_response(
@@ -419,9 +419,9 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
         # that way until we move here from django Wizard to horizon workflow
         if views.ADD_TO_FIELD_HEADER in self.request.META:
             field_id = self.request.META[views.ADD_TO_FIELD_HEADER]
-            response = http.HttpResponse(json.dumps(
-                [obj_id, html.escape(obj_name)]
-            ))
+            response = http.HttpResponse(
+                json.dumps([obj_id, html.escape(obj_name)]),
+                content_type='text/plain')
             response["X-Horizon-Add-To-Field"] = field_id
             return response
         else:
